==> qtjambi-network-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiNetwork/QNetworkReply_shell.h <==
#ifndef QNETWORKREPLY_SHELL_H
#define QNETWORKREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qnetworkreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkrequest.h>
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslerror.h>)
#include <QtNetwork/qsslerror.h>
#endif
#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#if __has_include(<QtNetwork/qsslpresharedkeyauthenticator.h>)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif
#endif //QT_CONFIG(ssl)
#include <QtJambi/RegistryAPI>


class QNetworkReply_shell : public QNetworkReply, public QtJambiShellInterface
{
public:
    QNetworkReply_shell(QObject* parent0 = nullptr);
    ~QNetworkReply_shell() override;

    void abort() override;
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void ignoreSslErrors() override;
    void ignoreSslErrorsImplementation(const QList<QSslError>& arg__1) override;
    bool isSequential() const override;
    bool open(QIODeviceBase::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    void setReadBufferSize(qint64 size0) override;
    void setSslConfigurationImplementation(const QSslConfiguration& arg__1) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize0) override;
    void sslConfigurationImplementation(QSslConfiguration& arg__1) const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkReply_access : public QNetworkReply
{
    void __qt_setAttribute_QNetworkRequest_Attribute_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint code0, jobject value1);
    void __qt_setError_QNetworkReply_NetworkError_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint errorCode0, jstring errorString1);
    void __qt_setFinished_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1);
    void __qt_setHeader_QNetworkRequest_KnownHeaders_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint header0, jobject value1);
    void __qt_setOperation_QNetworkAccessManager_Operation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0);
    void __qt_setRawHeader_cref_QByteArray_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID headerName0, QtJambiNativeID value1);
    void __qt_setRequest_cref_QNetworkRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_abort(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_ignoreSslErrors(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_ignoreSslErrorsImplementation_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    jboolean __qt_isSequential_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_setReadBufferSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    void __qt_setSslConfigurationImplementation_cref_QSslConfiguration(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_sslConfigurationImplementation_ref_QSslConfiguration_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QNETWORKREPLY_SHELL_H

==> qtjambi-network-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiNetwork/QNetworkReply_shell.h <==
#ifndef QNETWORKREPLY_SHELL_H
#define QNETWORKREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qnetworkreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkrequest.h>
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslerror.h>)
#include <QtNetwork/qsslerror.h>
#endif
#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#if __has_include(<QtNetwork/qsslpresharedkeyauthenticator.h>)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif
#endif //QT_CONFIG(ssl)
#include <QtJambi/RegistryAPI>


class QNetworkReply_shell : public QNetworkReply, public QtJambiShellInterface
{
public:
    QNetworkReply_shell(QObject* parent0 = nullptr);
    ~QNetworkReply_shell() override;

    void abort() override;
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void ignoreSslErrors() override;
    void ignoreSslErrorsImplementation(const QList<QSslError>& arg__1) override;
    bool isSequential() const override;
    bool open(QIODeviceBase::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    void setReadBufferSize(qint64 size0) override;
    void setSslConfigurationImplementation(const QSslConfiguration& arg__1) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize0) override;
    void sslConfigurationImplementation(QSslConfiguration& arg__1) const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkReply_access : public QNetworkReply
{
    void __qt_setAttribute_QNetworkRequest_Attribute_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint code0, jobject value1);
    void __qt_setError_QNetworkReply_NetworkError_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint errorCode0, jstring errorString1);
    void __qt_setFinished_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1);
    void __qt_setHeader_QNetworkRequest_KnownHeaders_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint header0, jobject value1);
    void __qt_setOperation_QNetworkAccessManager_Operation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0);
    void __qt_setRawHeader_cref_QByteArray_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID headerName0, QtJambiNativeID value1);
    void __qt_setRequest_cref_QNetworkRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_abort(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_ignoreSslErrors(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_ignoreSslErrorsImplementation_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    jboolean __qt_isSequential(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_setReadBufferSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    void __qt_setSslConfigurationImplementation_cref_QSslConfiguration(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_sslConfigurationImplementation_ref_QSslConfiguration_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QNETWORKREPLY_SHELL_H
